def fixturefunc():
    """ """
